==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QPolarChart_shell.h <==
#ifndef QPOLARCHART_SHELL_H
#define QPOLARCHART_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qpolarchart.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qchart.h>
#include <QtCharts/qlegend.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayout.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QPolarChart_shell : public QPolarChart, public QtJambiShellInterface
{
public:
    QPolarChart_shell(QGraphicsItem* parent0 = nullptr, Qt::WindowFlags wFlags1 = Qt::WindowFlags());
    ~QPolarChart_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void changeEvent(QEvent* event0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    void grabKeyboardEvent(QEvent* event0) override;
    void grabMouseEvent(QEvent* event0) override;
    void hideEvent(QHideEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void initStyleOption(QStyleOption* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void moveEvent(QGraphicsSceneMoveEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void paintWindowFrame(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void polishEvent() override;
    QVariant propertyChange(const QString& propertyName0, const QVariant& value1) override;
    void resizeEvent(QGraphicsSceneResizeEvent* event0) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    void setGeometry(const QRectF& rect0) override;
    QPainterPath shape() const override;
    void showEvent(QShowEvent* event0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void ungrabKeyboardEvent(QEvent* event0) override;
    void ungrabMouseEvent(QEvent* event0) override;
    void updateGeometry() override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    bool windowFrameEvent(QEvent* e0) override;
    Qt::WindowFrameSection windowFrameSectionAt(const QPointF& pos0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPolarChart_access : public QPolarChart
{
};

#endif // QPOLARCHART_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QPolarChart_shell.h <==
#ifndef QPOLARCHART_SHELL_H
#define QPOLARCHART_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qpolarchart.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qchart.h>
#include <QtCharts/qlegend.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayout.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QPolarChart_shell : public QPolarChart, public QtJambiShellInterface
{
public:
    QPolarChart_shell(QGraphicsItem* parent0 = nullptr, Qt::WindowFlags wFlags1 = Qt::WindowFlags());
    ~QPolarChart_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QPolarChart_mshell;
    friend class QPolarChart_oshell;
};


class QPolarChart_mshell : public QPolarChart_shell
{
public:
    using QPolarChart_shell::QPolarChart_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QPolarChart_oshell : public QPolarChart_mshell
{
public:
    using QPolarChart_mshell::QPolarChart_mshell;
    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void changeEvent(QEvent* event0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    void grabKeyboardEvent(QEvent* event0) override;
    void grabMouseEvent(QEvent* event0) override;
    void hideEvent(QHideEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void initStyleOption(QStyleOption* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void moveEvent(QGraphicsSceneMoveEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void paintWindowFrame(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void polishEvent() override;
    QVariant propertyChange(const QString& propertyName0, const QVariant& value1) override;
    void resizeEvent(QGraphicsSceneResizeEvent* event0) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    void setGeometry(const QRectF& rect0) override;
    QPainterPath shape() const override;
    void showEvent(QShowEvent* event0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void ungrabKeyboardEvent(QEvent* event0) override;
    void ungrabMouseEvent(QEvent* event0) override;
    void updateGeometry() override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    bool windowFrameEvent(QEvent* e0) override;
    Qt::WindowFrameSection windowFrameSectionAt(const QPointF& pos0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPolarChart_access : public QPolarChart
{
};

#endif // QPOLARCHART_SHELL_H
